---
title: Overview of Docker Build
description: Introduction and overview of Docker Build
keywords: build, buildx, buildkit
redirect_from:
  - /buildx/working-with-buildx/
  - /develop/develop-images/build_enhancements/
---

Docker Build is one of Docker Engine's most used features. Whenever you are
creating an image you are using Docker Build. Build is a key part of your
software development life cycle allowing you to package and bundle your code and
ship it anywhere.

Docker Build is more than a command for building images, and it's not only about
packaging your code. It's a whole ecosystem of tools and features that support
not only common workflow tasks but also provides support for more complex and
advanced scenarios.

<div class="component-container">
  <div class="row">
    <div class="col-xs-12 col-sm-12 col-md-12 col-lg-4 block">
      <div class="component">
        <div class="component-icon">
          <a href="/build/building/packaging/">
           <img src="/assets/images/build-packaging-software.svg" alt="Closed cardboard box" width="70px" height="70px">
          </a>
        </div>
        <h2><a href="/build/building/packaging/">Packaging your software</a></h2>
        <p>
          Build and package your application to run it anywhere: locally or in the cloud.
        </p>
      </div>
    </div>
    <div class="col-xs-12 col-sm-12 col-md-12 col-lg-4 block">
      <div class="component">
        <div class="component-icon">
          <a href="/build/building/multi-stage/">
           <img src="/assets/images/build-multi-stage.svg" alt="Staircase" width="70px" height="70px">
          </a>
        </div>
        <h2><a href="/build/building/multi-stage/">Multi-stage builds</a></h2>
        <p>
          Keep your images small and secure with minimal dependencies.
        </p>
      </div>
    </div>
    <div class="col-xs-12 col-sm-12 col-md-12 col-lg-4 block">
      <div class="component">
        <div class="component-icon">
          <a href="/build/building/multi-platform/">
           <img src="/assets/images/build-multi-platform.svg" alt="Stacked windows" width="70px" height="70px">
          </a>
        </div>
        <h2><a href="/build/building/multi-platform/">Multi-platform images</a></h2>
        <p>
          Build, push, pull, and run images seamlessly on different computer architectures.
        </p>
      </div>
    </div>
  </div>
  <div class="row">
    <div class="col-xs-12 col-sm-12 col-md-12 col-lg-4 block">
      <div class="component">
        <div class="component-icon">
          <a href="/build/architecture/">
           <img src="/assets/images/explore.svg" alt="Compass" width="70px" height="70px">
          </a>
        </div>
        <h2><a href="/build/architecture/">Architecture</a></h2>
        <p>
          Learn the Docker Build components.
        </p>
      </div>
    </div>
    <div class="col-xs-12 col-sm-12 col-md-12 col-lg-4 block">
      <div class="component">
        <div class="component-icon">
          <a href="/build/buildkit/">
           <img src="/assets/images/build-configure-buildkit.svg" alt="Hammer and screwdriver" width="70px" height="70px">
          </a>
        </div>
        <h2><a href="/build/buildkit/">BuildKit</a></h2>
        <p>
          Explore BuildKit, the open source builder engine.
        </p>
      </div>
    </div>
    <div class="col-xs-12 col-sm-12 col-md-12 col-lg-4 block">
      <div class="component">
        <div class="component-icon">
          <a href="/build/drivers/">
           <img src="/assets/images/build-drivers.svg" alt="Silhouette of an engineer, with cogwheels in the background" width="70px" height="70px">
          </a>
        </div>
        <h2><a href="/build/drivers/">Build drivers</a></h2>
        <p>
          Configure where and how you run your builds.
        </p>
      </div>
    </div>
  </div>
  <div class="row">
    <div class="col-xs-12 col-sm-12 col-md-12 col-lg-4 block">
      <div class="component">
        <div class="component-icon">
          <a href="/build/exporters/">
           <img src="/assets/images/build-exporters.svg" alt="Arrow coming out of a box" width="70px" height="70px">
          </a>
        </div>
        <h2><a href="/build/exporters/">Exporters</a></h2>
        <p>
          Export any artifact you like, not just Docker images.
        </p>
      </div>
    </div>
    <div class="col-xs-12 col-sm-12 col-md-12 col-lg-4 block">
      <div class="component">
        <div class="component-icon">
          <a href="/build/cache/">
           <img src="/assets/images/build-cache.svg" alt="Two arrows rotating in a circle" width="70px" height="70px">
          </a>
        </div>
        <h2><a href="/build/cache/">Build caching</a></h2>
        <p>
          Avoid unnecessary repetitions of costly operations, such as package installs.
        </p>
      </div>
    </div>
    <div class="col-xs-12 col-sm-12 col-md-12 col-lg-4 block">
      <div class="component">
        <div class="component-icon">
          <a href="/build/bake/">
           <img src="/assets/images/build-bake.svg" alt="Cake silhouette" width="70px" height="70px">
          </a>
        </div>
        <h2><a href="/build/bake/">Bake</a></h2>
        <p>
          Orchestrate your builds with Bake.
        </p>
      </div>
    </div>
  </div>
</div>
